# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Container(_OnPrem):
    _type = "container"
    _icon_dir = "resources/onprem/container"


class Docker(_Container):
    _icon = "docker.png"


class Rkt(_Container):
    _icon = "rkt.png"


# Aliases

RKT = Rkt



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Connectivity(_OCI):
    _type = "connectivity"
    _icon_dir = "resources/oci/connectivity"


class Backbone(_Connectivity):
    _icon = "backbone.png"


class Customerdatacenter(_Connectivity):
    _icon = "customerdatacenter.png"


class Customerpremisesequip(_Connectivity):
    _icon = "customerpremisesequip.png"


class Fastconnect(_Connectivity):
    _icon = "fastconnect.png"


class Vpn(_Connectivity):
    _icon = "vpn.png"


# Aliases
